import WebSocketClient from "./services/websocket.js";
import MessageRouter from "./services/messagerouter.js";
import { messageConfig } from "./protocol/config.js";
import { ws, state } from "./services/stateservice.js";
import ui from "./views/ui.js";

const messageRouter = new MessageRouter();
const webSocketClient = new WebSocketClient(
  `${state.hostData.wsProtocol}${state.hostData.host}/remobster/session/ws`,
  messageRouter
);

document.addEventListener("DOMContentLoaded", () => {
  webSocketClient
    .connect()
    .then(() => {
      console.log("Connected!");
      sendJoinMobSession(state.sessionId);
    })
    .catch((error) => {
      console.error("WebSocket connection error:", error);
      throw Error("App could not connect to the websocket server.");
    });

  Object.keys(messageConfig).forEach((messageType) => {
    messageRouter.subscribe(messageType, messageConfig[messageType]);
  });

  ws.webSocketClient = webSocketClient;

  console.log("connecting...!");
  ui.init();
  ui.registerActions();
});

function sendJoinMobSession(id) {
  webSocketClient.sendMessage(
    JSON.stringify({
      type: "JOIN",
      sessionId: id,
      payload: {
        userName: state.username,
        userId: state.userId,
      },
    })
  );
}
