import { updateDriverState, timer } from "../services/stateservice.js";
import rotationListView from "../views/components/rotationListView.js";
import timeInfoConfigView from "../views/components/timeInfoConfigView.js";
import startButtonView from "../views/components/startButtonView.js";
import timerView from "../views/components/timerView.js";
import rejoinView from "../views/components/rejoinView.js";
import resetTimerView from "../views/components/resetTimerView.js";

export const messageConfig = {
  NEW_MEMBER: (message) => {
    console.log("NEW MEMBER JOINED!");
    rotationListView.updateUserRotationQueue(message.driverRotationQueue);
    timer.config.minutesForDriver = message.config.driverRotationTimeInMinutes;
    // timeInfoConfigView.updateConfigView(message);
    timerView.updateTimerWhenConfigIsChanged(message.timerInfo);
    startButtonView.updateIfDriver(message);
    if (timerView.running()) {
      console.log("running, need to change start button to pause.");
      startButtonView.changeToPause();
      resetTimerView.show();
    }
    updateDriverState(message.driverRotationQueue);
  },

  ROTATION_QUEUE_UPDATE: (message) => {
    console.log("Rotation queue update");
    rotationListView.updateUserRotationQueue(message.driverRotationQueue);

    startButtonView.updateIfDriver(message);
    if (timerView.running()) {
      console.log("running, need to change start button to pause.");
      startButtonView.changeToPause();
    }

    updateDriverState(message.driverRotationQueue);
    rejoinView.update(message.driverRotationQueue);
  },

  MEMBER_LEAVE: (message) => {
    rotationListView.updateUserRotationQueue(message.driverRotationQueue);
    updateDriverState(message.driverRotationQueue);
    startButtonView.updateIfDriver(message);
  },

  CONFIG_UPDATE: (message) => {
    console.log("A config update...", message);
    timeInfoConfigView.updateConfigView(message);
    timerView.updateTimerWhenConfigIsChanged();
  },

  START_NEW_ROTATION: (message) => {
    console.log("NEW ROTATION");
    timerView.startCountDown(message);
    updateDriverState(message.driverRotationQueue);
    startButtonView.updateIfDriver(message);
    startButtonView.changeToPause();
    resetTimerView.show();
    window.electronAPI.closeFullScreen();
  },

  PAUSE: (message) => {
    console.log("PAUSE MESSAGE");
    timerView.pauseCounter(message);
  },

  HAND_OVER: (message) => {
    console.log("it is time to changes drivers!");
    window.electronAPI.closeFullScreen();
    timerView.updateTimerWhenConfigIsChanged();
    rotationListView.updateUserRotationQueue(message.driverRotationQueue);
    startButtonView.updateIfDriver(message);
  },
  RESET_TIMER: (message) => {
    console.log("A reset timer message was received from the server", message);
    timerView.resetTimer();
    startButtonView.changeToStart();
    resetTimerView.hide();
  },
};
