import { state } from "./stateservice.js";

export default class WebSocketClient {
  constructor(url, messageRouter) {
    this.url = url;
    this.socket = null;
    this.messageRouter = messageRouter;
  }

  connect() {
    return new Promise((resolve, reject) => {
      this.socket = new WebSocket(this.url, ["remobster", state.license]);

      this.socket.onopen = () => {
        console.log("WebSocket connected.");
        resolve();
      };

      this.socket.onerror = (error) => {
        console.error("WebSocket error:", error);
        reject(error);
        window.location.href = "../lobby.html?wserror=true";
      };

      this.socket.onmessage = (event) => {
        const message = JSON.parse(event.data);
        this.messageRouter.route(message);
      };

      this.socket.onclose = () => {
        console.log("WebSocket closed.");
        window.location.href = "../lobby.html?wsclosed=true";
      };
    });
  }

  sendMessage(message) {
    if (this.socket && this.socket.readyState === WebSocket.OPEN) {
      this.socket.send(message);
    }
  }
}
