import { state } from "../../services/stateservice.js";
const rotationListElement = document.getElementById("rotation-list");
const store = {
  userRotationQueue: [{ name: "dummy", id: "000AAA" }],
  subscribers: [],
};

function updateRotationList() {
  const users = store.userRotationQueue;
  rotationListElement.replaceChildren();
  users.forEach((user, index) => createRotationGroup(user, index));
}

function createRotationGroup(user, index) {
  const div = document.createElement("div");
  div.className = "user";
  div.dataset.name = user.name;
  div.dataset.id = user.id;
  div.dataset.index = index;
  div.style.display = "flex";
  const leftArrow = document.createElement("i");
  leftArrow.classList.add("ph", "ph-arrow-fat-lines-left");
  leftArrow.onclick = onClickLeft;

  const nameSpan = document.createElement("span");
  nameSpan.innerText = `${user.name} - ${user.id.substring(0, 6)}`;
  nameSpan.className = "name";

  if (index === 0) {
    nameSpan.classList.add("driver");
  }

  if (user.id === state.userId) {
    nameSpan.classList.add("current");
  }

  const deleteUserIcon = document.createElement("i");
  deleteUserIcon.classList.add("ph", "ph-user-circle-minus");
  deleteUserIcon.onclick = onClickDeleteUser;

  const rightArrow = document.createElement("i");
  rightArrow.classList.add("ph", "ph-arrow-fat-lines-right");
  rightArrow.onclick = onClickRight;

  div.appendChild(leftArrow);
  div.appendChild(nameSpan);

  div.appendChild(deleteUserIcon);

  div.appendChild(rightArrow);
  rotationListElement.appendChild(div);
}

function onClickDeleteUser(event) {
  const parent = event.target.parentElement;
  rotationListElement.removeChild(parent);
  notifyOnChangeOrderSubscribers();
  //TODO: DELETE command.
}

function onClickLeft(event) {
  const parent = event.target.parentElement;

  if (parent === rotationListElement.firstElementChild) {
    rotationListElement.removeChild(parent);
    rotationListElement.appendChild(parent);
  } else {
    rotationListElement.insertBefore(parent, parent.previousElementSibling);
  }
  notifyOnChangeOrderSubscribers();
}

function onClickRight(event) {
  console.log("clicked right arrow", event.target.parentElement.dataset.index);

  const parent = event.target.parentElement;

  if (parent === rotationListElement.lastElementChild) {
    rotationListElement.removeChild(parent);
    rotationListElement.insertBefore(parent, rotationListElement.firstElementChild);
  } else {
    rotationListElement.insertBefore(parent.nextElementSibling, parent);
  }
  notifyOnChangeOrderSubscribers();
}

function notifyOnChangeOrderSubscribers() {
  store.userRotationQueue = getListValues();
  store.subscribers.forEach((callback) => callback(store.userRotationQueue));
}

function getListValues() {
  const listItems = rotationListElement.querySelectorAll("div");
  console.log("list value", listItems);
  const values = Array.from(listItems).map((item) => {
    return { id: item.dataset.id, name: item.dataset.name };
  });

  //make it unique
  const uniqueMap = new Map(values.map((item) => [item["id"], item]));
  return Array.from(uniqueMap.values());
}

export default {
  init: () => {
    updateRotationList();
  },

  updateUserRotationQueue: (data) => {
    store.userRotationQueue = data;
    updateRotationList();
  },

  onChangeOrder: (callback) => {
    store.subscribers.push(callback);
  },

  getRotationQueue: () => {
    return store.userRotationQueue;
  },
};
