import { timer } from "../../services/stateservice.js";
const driverMinutes = document.getElementById("driver-session-minutes");
const configForm = document.getElementById("config-form");

const store = {
  subscribers: [],
};

configForm.addEventListener("submit", (e) => {
  e.preventDefault(); //just stop the form from submitting when pressing enter.
});

const invalidChars = ["-", "+", "e"];

driverMinutes.addEventListener("input", function () {
  this.value = this.value.replace(/[e\+\-]/gi, "");
});

driverMinutes.addEventListener("keydown", function (e) {
  if (invalidChars.includes(e.key)) {
    e.preventDefault();
  }
});

function validateThatValueIsNumberWithinRange(value) {
  const numberValue = Number(value);
  return Number.isInteger(numberValue) && numberValue >= 1 && numberValue <= 60;
}

driverMinutes.addEventListener("change", (e) => {
  if (!validateThatValueIsNumberWithinRange(driverMinutes.value)) {
    console.log("invalid config", driverMinutes.value);
    return;
  }
  timer.config.minutesForDriver = driverMinutes.value;
  updateElementWithValues();
  notifySubscribersOnChangeConfiguration();
});

function updateElementWithValues() {
  driverMinutes.value = timer.config.minutesForDriver;
}

function notifySubscribersOnChangeConfiguration() {
  store.subscribers.forEach((c) => c(timer.config));
}

export default {
  init: () => {
    //nothing or set default values?
  },

  updateConfigView: (data) => {
    timer.config.minutesForDriver = data.config.driverRotationTimeInMinutes;
    updateElementWithValues();
  },

  onChangeConfiguration: (callback) => {
    store.subscribers.push(callback);
  },
};
