import { timer, state } from "../../services/stateservice.js";

//this should probably not be owned by the timer view
const store = {
  startTime: timer.config.minutesForDriver * 1000 * 60,
  timeLeft: timer.config.minutesForDriver * 1000 * 60,
  timerIntervalId: undefined,
  running: false,
  pause: false,
  subscribers: [],
  tickSubscribers: [],
};

const timeElement = document.getElementById("timer");

function updateDisplay(timeLeft) {
  const minutes = Math.floor(timeLeft / 60000);
  const seconds = Math.floor((timeLeft % 60000) / 1000);
  const text = `${minutes.toString().padStart(2, "0")}:${seconds.toString().padStart(2, "0")}`;
  timeElement.innerHTML = text;
  store.tickSubscribers.forEach((callback) => callback({ text, timeLeft }));
}

const audio = new Audio("../audio/times-up.wav");

function updateDisplayWithTimesUp() {
  if (state.driver) {
    audio.play();
  }

  timeElement.innerHTML = "Time's Up!";
}

function updateFromStoredConfig() {
  const inMinutes = timer.config.minutesForDriver;
  const inMillis = inMinutes * 60 * 1000;
  updateDisplay(inMillis);
}

function startTimer(resetTimer) {
  console.log("this is called now.");
  if (resetTimer) {
    store.timeLeft = store.startTime;
    clearInterval(store.timerIntervalId);
    store.running = true;
    store.pause = false;
  }
  store.timerIntervalId = setInterval(timerTick, 1000);
}

function timerTick() {
  store.timeLeft -= 1000;

  updateDisplay(store.timeLeft);
  if (store.timeLeft > 0) {
    //what to do when we have time left?
  } else {
    clearInterval(store.timerIntervalId);
    store.running = false;
    updateDisplayWithTimesUp();
    notifyOnTimesUpSubscribers();
  }
}

function notifyOnTimesUpSubscribers() {
  store.subscribers.forEach((callback) => callback());
}

function setPause(timeLeftInMs) {
  store.running = false;
  store.pause = true;
  clearInterval(store.timerIntervalId);
  store.timeLeft = timeLeftInMs;
  updateDisplay(store.timeLeft);
}

export default {
  init: () => {
    // updateFromStoredConfig();
  },

  onTimesUp: (callback) => {
    store.subscribers.push(callback);
  },

  onTick: (callback) => {
    store.tickSubscribers.push(callback);
  },

  updateTimerWhenConfigIsChanged: (timerInfo) => {
    if (timerInfo?.paused) {
      setPause(timerInfo.pausedTimeLeftInMs);
    }

    if (timerInfo?.inRotation) {
      store.startTime = timerInfo.timeLeftInMs;
      store.timeLeft = store.startTime;
      updateDisplay(store.timeLeft);
      startTimer(true);
    }

    if (!store.running && !store.pause) {
      updateFromStoredConfig();
    }
  },

  set1Minute: () => {
    updateDisplay(60 * 1000 * 1);
  },

  startCountDown: (message) => {
    store.startTime = message.rotationTime;
    startTimer(true);
  },

  pauseCounter: (message) => {
    setPause(message.timeLeftInMs);
  },

  timeLeft: () => {
    return store.timeLeft;
  },

  paused: () => {
    return store.pause;
  },

  running: () => {
    return store.running;
  },

  resetTimer: () => {
    store.timeLeft = store.startTime;
    clearInterval(store.timerIntervalId);
    store.running = false;
    store.pause = false;
    updateDisplay(store.timeLeft);
  },
};
