import usernameview from "./components/usernameview.js";
import sessionInfoView from "./components/sessionInfoView.js";
import rotationListView from "./components/rotationListView.js";
import timeInfoConfigView from "./components/timeInfoConfigView.js";
import startButtonView from "./components/startButtonView.js";
import timerView from "./components/timerView.js";
import handOverView from "./components/handOverView.js";
import rejoinView from "./components/rejoinView.js";
import resetTimerView from "./components/resetTimerView.js";

import { timer, state } from "../services/stateservice.js";
import {
  sendRotationQueueUpdate,
  sendTimeInfoUpdate,
  sendRotationStart,
  sendRotationPause,
  sendHandOverMessage,
  sendResetTimer,
} from "../protocol/sendConfig.js";

import generateTrayIcon from "../services/trayIconGenerator.js";

export default {
  init: () => {
    usernameview.init();
    sessionInfoView.init();
    rotationListView.init();
    timeInfoConfigView.init();
    timerView.init();
    startButtonView.init();
    handOverView.init();
    generateTrayIcon("--:--");
    rejoinView.init();
    resetTimerView.init();
  },

  registerActions: () => {
    rotationListView.onChangeOrder(sendRotationQueueUpdate);
    timeInfoConfigView.onChangeConfiguration(sendTimeInfoUpdate);

    startButtonView.onStartClick((state) => {
      if (state == "START") {
        if (timerView.paused()) {
          sendRotationStart(timerView.timeLeft());
        } else {
          sendRotationStart(timer.config.minutesForDriver * 60 * 1000);
        }
      } else {
        sendRotationPause(timerView.timeLeft());
      }
    });

    timerView.onTimesUp(() => {
      if (!state.inRotation) {
        console.log("Not part of rotation, doing nothing");
        return;
      }

      window.electronAPI.openFullScreen();
      handOverView.showButtons();
      startButtonView.hide();
    }); //For now pop the

    resetTimerView.onClick(() => {
      console.log("on click reset timer");
      sendResetTimer();
    });

    timerView.onTick((data) => {
      generateTrayIcon(data.text);
      if (data.timeLeft === 61 * 1000) {
        new Notification("1 Minute Left!", { body: "It's soon time to commit and push!" });
      }
    });

    handOverView.onClickHandOver(sendHandOverMessage);
    handOverView.onClickExtraTimeButton(() => {
      if (!state.inRotation) {
        console.log("Not part of rotation, doing nothing");
        return;
      }

      window.electronAPI.closeFullScreen();
      timerView.set1Minute();
      sendRotationStart(59 * 1 * 1000);
    });

    rejoinView.onClickRejoin(() => {
      //this is a hack.. should move rotation state to its own service/class instead
      //of using the view as data holder...
      const queue = rotationListView.getRotationQueue();
      queue.push({
        id: state.userId,
        name: state.username,
      });
      sendRotationQueueUpdate(queue);
    });
  },
};
